@@ -1,4 +1,4 @@
-model.syntax <- '
+model.syntax <- "
   # intercept and slope with fixed coefficients
     i =~ 1*t1 + 1*t2 + 1*t3 + 1*t4
     s =~ 0*t1 + 1*t2 + 2*t3 + 3*t4
@@ -12,8 +12,8 @@ model.syntax <- '
     t2 ~ c2
     t3 ~ c3
     t4 ~ c4
-'
+"
 
 fit <- growth(model.syntax, data = Demo.growth)
 lavaangui(fit)
-plot_interactive(fit)
+plot_lavaan(fit)
